pub struct CommandPublisher<Pub> { /* private fields */ }Expand description
A struct for publishing commands
Implementations
Sourceimpl<Pub> CommandPublisher<Pub>
impl<Pub> CommandPublisher<Pub>
Sourcepub fn new(publisher: Pub, topic: &str) -> CommandPublisher<Pub>
pub fn new(publisher: Pub, topic: &str) -> CommandPublisher<Pub>
Creates an new command publisher configured with the given publisher that will send to the specified topic
Sourceimpl<Pub: Publisher> CommandPublisher<Pub>
impl<Pub: Publisher> CommandPublisher<Pub>