pub struct Host {
pub components: HashMap<String, usize>,
pub friendly_name: String,
pub labels: HashMap<String, String>,
pub providers: HashSet<ProviderInfo>,
pub uptime_seconds: usize,
pub version: Option<Version>,
pub id: String,
pub last_seen: DateTime<Utc>,
}Expand description
A wasmCloud host
Fields
components: HashMap<String, usize>A map of component IDs to the number of instances of the component running on the host
friendly_name: StringThe randomly generated friendly name of the host
labels: HashMap<String, String>An arbitrary hashmap of string labels attached to the host
providers: HashSet<ProviderInfo>A set of running providers on the host
uptime_seconds: usizeThe current uptime of the host in seconds
version: Option<Version>The host version that is running
id: StringThe ID of this host, in the form of its nkey encoded public key
last_seen: DateTime<Utc>The time when this host was last seen, as a RFC3339 timestamp